using GraphicsManager.Interfaces;
using GraphicsManager.Objects;
using GraphicsManager.Objects.Core;
using Luski.net.Structures.Public;
using Luski.Shared.PublicServers.V1.Enums;
using OpenTK.Mathematics;

namespace Luski.GUI.MainScreen.UI.LuskiControls;

public class ProfileView : UserControl
{
    public SocketUser User { get; set; }

    private ProfileView(IRenderObject user, SocketUser u, ServerProfile p, Role r, Color[] c, ColorType ct)
    {
        this.User = u;
        base.Size = new(244.ScaleInt(), 44.ScaleInt());
        base.BackgroundColor = new(34, 34, 34, 255);
        user.Location = new(8.ScaleInt(), 6.ScaleInt(), 0);
        user.ForceDistanceUpdate(this);
        user.IgnoreHover = true;

        LabelBase uname;
        if (ct == ColorType.Full)
        {
            uname = new Label(Globals.DefaultFont)
            {
                Text = p.DisplayName,
                Color = c[0].ToColor4(),
                IgnoreHover = true
            };
        }
        else
        {
            uname = new AdvancedGradientLabel(Globals.DefaultFont)
            {
                Text = p.DisplayName,
                Colors = c.ToColor4Array(),
                IgnoreHover = true
            };
        }
        
        uname.Location = new(user.Location.X + user.Size.X + 8.ScaleInt(),
            (user.Location.Y + (user.Size.Y / 2) - (uname.Size.Y / 2)), 0);
        Controls.Add(uname);
        Controls.Add(user);
    }
    
    public static async Task<ProfileView> Make(SocketUser u, ServerProfile p, Role r)
    {
        ColorType ct = await u.GetColorType();
        Color[] c = await u.GetColors();
        ColorType? cct = await p.GetColorType();
        Color[]? cc = await p.GetColors();
        if (cc is not null)
        {
            c = cc;
            ct = cct!.Value;  
        }
        ProfileView m = new(await p.MakeRct(u, new(32.ScaleInt())), u, p, r, c, ct);
        return m;
    }
}