using GraphicsManager.Interfaces;
using GraphicsManager.Objects;
using GraphicsManager.Objects.Core;
using Luski.net.Structures.Public;
using Luski.Shared.PublicServers.V1.Enums;
using OpenTK.Mathematics;

namespace Luski.GUI.MainScreen.UI.LuskiControls;

public class UserView : UserControl
{
    public SocketUser User { get; set; }

    private UserView(IRenderObject user, SocketUser u, ServerProfile p, Role r, bool offline)
    {
        this.User = u;
        base.Size = new(244.ScaleInt(), 44.ScaleInt());
        base.BackgroundColor = new(34, 34, 34, 255);
        user.Location = new(8.ScaleInt(), 6.ScaleInt(), 0);
        user.ForceDistanceUpdate(this);
        if (r.ColorType == ColorType.Full)
        {
            Label uname = new(Globals.DefaultFont)
            {
                Text = p.DisplayName,
                Color = r.Colors[0].ToColor4()
            };
            if (offline) uname.Color = new(uname.Color.R, uname.Color.G, uname.Color.B, uname.Color.A * 0.6f);
            uname.Location = new(user.Location.X + user.Size.X + 8.ScaleInt(),
                (user.Location.Y + (user.Size.Y / 2) - (uname.Size.Y / 2)), 0);
            Controls.Add(uname);
        }
        else
        {
            AdvancedGradientLabel uname = new(Globals.DefaultFont)
            {
                Text = p.DisplayName,
                Colors = r.Colors.ToColor4Array()
            };
            if (offline)
            {
                for (int i = 0; i < uname.Colors.Length; i++)
                {
                    uname.Colors[i] = new(uname.Colors[i].R, uname.Colors[i].G, uname.Colors[i].B,
                        uname.Colors[i].A * 0.6f);
                }
            }
            uname.Location = new(user.Location.X + user.Size.X + 8.ScaleInt(),
                (user.Location.Y + (user.Size.Y / 2) - (uname.Size.Y / 2)), 0);
            Controls.Add(uname);
        }
        Controls.Add(user);
    }
    
    public static async Task<UserView> Make(SocketUser u, ServerProfile p, Role r, bool offline)
    {
        UserView m = new(await p.MakeRct(u, new(32.ScaleInt())), u, p, r, offline);
        return m;
    }
}